==> mx-tools_21.8.02.tar.xz: mx-tools-21.8.02/translations/mx-tools_zh_TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_TW">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="411"/>
        <source>MX Tools</source>
        <translation type="unfinished">MX 工具組</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="53"/>
        <source>About this application</source>
        <translation type="unfinished">關於本程式</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="56"/>
        <source>About...</source>
        <translation type="unfinished">關於……</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="63"/>
        <source>Alt+B</source>
        <translation type="unfinished">Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="127"/>
        <source>Close application</source>
        <translation type="unfinished">關閉程式</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="130"/>
        <source>Close</source>
        <translation type="unfinished">關閉</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="137"/>
        <source>Alt+N</source>
        <translation type="unfinished">Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="165"/>
        <source>Manual</source>
        <translation type="unfinished">使用手冊</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="263"/>
        <source>These MX applications save time and effort with important tasks.</source>
        <translation type="unfinished">這些 MX 程式可以為你完成重要事項，節省時間與心力。</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="279"/>
        <source>Hide individual tools from the menu</source>
        <translation type="unfinished">在主選單中隱藏個別工具</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="298"/>
        <source>search</source>
        <translation type="unfinished">搜尋</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="410"/>
        <source>About MX Tools</source>
        <translation type="unfinished">關於 MX 工具組</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="411"/>
        <source>Version: </source>
        <translation type="unfinished">版本：</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="413"/>
        <source>Configuration Tools for MX Linux</source>
        <translation type="unfinished">MX Linux 的設定工具</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="414"/>
        <source>Copyright (c) MX Linux</source>
        <translation type="unfinished">版權所有 (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="415"/>
        <source>License</source>
        <translation type="unfinished">授權條款</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="416"/>
        <source>Changelog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="417"/>
        <source>Cancel</source>
        <translation type="unfinished">取消</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="432"/>
        <source>&amp;Close</source>
        <translation type="unfinished">關閉（&amp;C）</translation>
    </message>
</context>
<context>
    <name>mxtools</name>
    <message>
        <source>MX Tools</source>
        <translation type="vanished">MX 工具組</translation>
    </message>
    <message>
        <source>About this application</source>
        <translation type="vanished">關於本程式</translation>
    </message>
    <message>
        <source>About...</source>
        <translation type="vanished">關於……</translation>
    </message>
    <message>
        <source>Alt+B</source>
        <translation type="vanished">Alt+B</translation>
    </message>
    <message>
        <source>Close application</source>
        <translation type="vanished">關閉程式</translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="vanished">關閉</translation>
    </message>
    <message>
        <source>Alt+N</source>
        <translation type="vanished">Alt+N</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation type="vanished">使用手冊</translation>
    </message>
    <message>
        <source>These MX applications save time and effort with important tasks.</source>
        <translation type="vanished">這些 MX 程式可以為你完成重要事項，節省時間與心力。</translation>
    </message>
    <message>
        <source>Hide individual tools from the menu</source>
        <translation type="vanished">在主選單中隱藏個別工具</translation>
    </message>
    <message>
        <source>search</source>
        <translation type="vanished">搜尋</translation>
    </message>
    <message>
        <source>About MX Tools</source>
        <translation type="vanished">關於 MX 工具組</translation>
    </message>
    <message>
        <source>Version: </source>
        <translation type="vanished">版本：</translation>
    </message>
    <message>
        <source>Configuration Tools for MX Linux</source>
        <translation type="vanished">MX Linux 的設定工具</translation>
    </message>
    <message>
        <source>Copyright (c) MX Linux</source>
        <translation type="vanished">版權所有 (c) MX Linux</translation>
    </message>
    <message>
        <source>License</source>
        <translation type="vanished">授權條款</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="vanished">取消</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="vanished">關閉（&amp;C）</translation>
    </message>
</context>
</TS>

==> mx-tools_23.7.01.tar.xz: mx-tools-23.7.01/translations/mx-tools_zh_TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_TW">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="411"/>
        <source>MX Tools</source>
        <translation>MX 工具組</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="53"/>
        <source>About this application</source>
        <translation>關於本程式</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="56"/>
        <source>About...</source>
        <translation>關於……</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="63"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="127"/>
        <source>Close application</source>
        <translation>關閉程式</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="130"/>
        <source>Close</source>
        <translation>關閉</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="137"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="165"/>
        <source>Manual</source>
        <translation>手動</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="274"/>
        <source>These MX applications save time and effort with important tasks.</source>
        <translation>這些 MX 程式可以為你完成重要事項，節省時間與心力。</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="290"/>
        <source>Hide individual tools from the menu</source>
        <translation>在主選單中隱藏個別工具</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="309"/>
        <source>search</source>
        <translation>搜尋</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="410"/>
        <source>About MX Tools</source>
        <translation>關於 MX 工具組</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="411"/>
        <source>Version: </source>
        <translation>版本：</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="412"/>
        <source>Configuration Tools for MX Linux</source>
        <translation>MX Linux 的設定工具</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="415"/>
        <source>Copyright (c) MX Linux</source>
        <translation>MX Linux 版權所有 (c)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="416"/>
        <source>%1 License</source>
        <translation>%1 許可</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="40"/>
        <source>License</source>
        <translation>授權條款</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="41"/>
        <location filename="../about.cpp" line="51"/>
        <source>Changelog</source>
        <translation>變更紀錄</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="42"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="64"/>
        <source>&amp;Close</source>
        <translation>關閉（&amp;C）</translation>
    </message>
</context>
</TS>
